@@ -22,8 +22,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 
-#include <Rmath.h>
 #include <stdio.h>
+#include "def.h"
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "questions.h"
 #include "shape.h"
 #include "operator.h"
@@ -169,7 +172,7 @@ int struct_Zhou(model *cov, model **newmodel){
   int err = NOERROR;
 
   ASSERT_NEWMODEL_NULL;
-  if (cov->Spgs != NULL)  pgs_DELETE(&(cov->Spgs));
+  if (cov->Spgs != NULL)  pgs_DELETE(&(cov->Spgs), cov);
 
   if (!hasSmithFrame(shape)) ILLEGAL_FRAME;
   if (cov->sub[PGS_LOC] == NULL) {
@@ -338,7 +341,7 @@ model *prunecov(model *newmodel, model *cov) {
   else BUG;
   next = *sub;
   *sub = NULL;
-  COV_DELETE(&newmodel);
+  COV_DELETE(&newmodel, cov);
   return next;
 }
 
@@ -1623,7 +1626,7 @@ int struct_Ballani(model *cov, model **newmodel){
   int err = NOERROR;
 
   ASSERT_NEWMODEL_NULL;
-  if (cov->Spgs != NULL)  pgs_DELETE(&(cov->Spgs));
+  if (cov->Spgs != NULL)  pgs_DELETE(&(cov->Spgs), cov);
 
   if (!hasPoissonGaussFrame(shape)) ILLEGAL_FRAME;
   if (cov->sub[PGS_LOC] == NULL) {
