@@ -20,6 +20,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
  
+#include "def.h"
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "questions.h"
 #include "operator.h"
 #include "Processes.h"
@@ -1298,7 +1302,7 @@ int setgatter_but_nr(model *cov, int minp, int maxp, int mino, int maxo,
       if (GATTERXDIM(i) != PREVXDIM(i)) BUG;
     }
     set_cumxmit(GATTER, i, GATTERXDIM(i));
-    if (i>0) set_cumxmit(GATTER, i, CUMXMIT(GATTER, i) + CUMXMIT(GATTER, i-1)); 
+    //if (i>0) set_cumxmit(GATTER, i, CUMXMIT(GATTER, i) + CUMXMIT(GATTER, i-1)); 
   }
   //  PSYS(cov); 
   set_trafo(UNSET);
