@@ -30,15 +30,15 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 
- 
+
+#include "def.h"
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "questions.h"
 #include "Processes.h"
 #include "families.h"
 #include "Coordinate_systems.h"
-//#include <R_ext/Lapack.h>
-//#include <R_ext/Applic.h>
-//#include <R_ext/Utils.h>     
-//#include <R_ext/BLAS.h> 
 
 
 void kdefault(model *cov, int i, double v) {
@@ -895,7 +895,7 @@ void assert_sys(system_type VARIABLE_IS_NOT_USED * sys){assert(sys != NULL);}
 //void assert_cov(model VARIABLE_IS_NOT_USED *cov) {assert(cov != NULL || __extension__({crash(); false;}));}
 //
 void assert_cov(model VARIABLE_IS_NOT_USED *cov) {
-  // if (cov==NULL) crash();
+  //if (cov==NULL) crash();
   assert(cov != NULL);
 }
 
