@@ -26,8 +26,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define RFsimu_H 1
 
 // ACHTUNG : REIHENFOLGE WICHTIG
-#include <Basic_utils.h>
-#include "def.h"
 #include "basic.h"
 #include "init.h"
 
@@ -48,8 +46,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // #define MEMCOPY(A,B,C) memory_copy(A, B, C)
 
 
-#include <string.h>
-#include <General_utils.h>
 #include "AutoRandomFields.h"
 #include "auxiliary.h"
 #include "RandomFields.h"
@@ -759,7 +755,7 @@ typedef struct likelihood_storage {
   bool dettrend_has_nas, fixedtrend_has_nas, random_has_nas, 
     data_has_nas,
     betas_separate, ignore_trend;
-  char *(betanames[MAX_LIN_COMP]);
+  char *betanames[MAX_LIN_COMP];
   model *cov_fixed[MAX_LIN_COMP], *cov_det[MAX_LIN_COMP], 
     *cov_random[MAX_LIN_COMP];
   likelihood_info info;
