@@ -5,7 +5,7 @@
  Martin Schlather, schlather@math.uni-mannheim.de
 
 
- Copyright (C) 2015 Martin Schlather
+ Copyright (C) 2015 -- 2017 Martin Schlather
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -29,12 +29,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef GSL_VS_R_H
 #define GSL_VS_R_H 1
 
-#include <R.h>
-#include <Rinternals.h>
-#include <Rmath.h>
-#include <errno.h>
-#include <R_ext/Complex.h>
-
 #ifdef SCHLATHERS_MACHINE
 #undef SCHLATHERS_MACHINE
 #endif
@@ -58,14 +52,15 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define MAXINVERSIONS 2
 
 
+#ifdef __GNUC__
+#define HIDE_UNUSED_VARIABLE 1
+#endif
 
-
-
-//
-// 
-// 
-// 
-
+#if __GNUC__ >= 7
+#define FALLTHROUGH_OK __attribute__ ((fallthrough));
+#else
+#define FALLTHROUGH_OK   
+#endif      
 
 
 #endif /* GSL_VS_R_H */
