@@ -21,17 +21,17 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#include <Rmath.h>
 #include <stdio.h>  
-//#include <stdlib.h>
+#include "def.h"
+#include <Basic_utils.h>
 #include <R_ext/Lapack.h>
 
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "questions.h"
 #include "Coordinate_systems.h"
 #include "Processes.h"
 #include "variogramAndCo.h"
-//#include "userinterfaces.h"
-//#include <R_ext/Linpack.h>
 
 
 int check_directGauss(model *cov) {
@@ -57,7 +57,7 @@ int check_directGauss(model *cov) {
   isotropy_type iso = CoordinateSystemOf(OWNISO(0));
   for (j=0; j<=1; j++) {
     if ((err = CHECK(next, OWNLOGDIM(0), OWNXDIM(0), type, dom, iso,
-		     SUBMODEL_DEP, EvaluationType)) == NOERROR) break;
+		     SUBMODEL_DEP, GaussMethodType)) == NOERROR) break;
     type = VariogramType;
     iso = SymmetricOf(OWNISO(0));
   }
