@@ -32,6 +32,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <stdio.h>  
 #include <string.h>
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "RF.h"
 #include "operator.h"
 #include "startGetNset.h"
@@ -284,7 +287,13 @@ bool CheckListmodel(){
   assert(LAST_ISO == 19); // otherwise change ISO_NAMES
   //  assert(MAXMPPDIM <= MAXSIMUDIM); // ZERO
   // assert(CUTOFF_THEOR == 4);/* do not change this value as used in RFmethods.Rd */
-  
+
+#define ntypefcts 18
+  const char *typefcts[ntypefcts] =
+    {"+", "*", "$", "$power", "fixcov",
+     "identity", "M", "matern", "tbm", "U",
+     "whittle", "nugget", "null", "trend", "trafo",
+     "setparam", "p", "c"};
 
   int nr, err=NOERROR;
   defn *C;
@@ -342,6 +351,20 @@ bool CheckListmodel(){
 	    (C->variants == 3 || equalsUnreduced(ISO(C->systems[3], 0))))
 	   )) goto ErrorHandling;
 
+    err = 8;
+    if (C->TypeFct != NULL && C->name[0] != '-') {
+      int i;
+      for (i=0; i<ntypefcts; i++) if (!STRCMP(typefcts[i], C->name)) break;
+      if (i >=ntypefcts) {
+	PRINTF("read instructions for typefcts: '%s'\n", C->name);
+	/* 
+	   instructions: note that is** in questions.h has a different
+	   behavious if typefct is given. Check and enter in the list if ok.
+	 */
+	//	goto ErrorHandling;
+      }
+    }
+
   }
   return true;
 
