@@ -22,16 +22,15 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 
-//#include <Rmath.h>
-//#include <stdio.h> 
-//#include <R_ext/Lapack.h>
-//
+#include "def.h"
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "questions.h"
 #include "operator.h"
 #include "Processes.h"
 #include "startGetNset.h"
 #include "variogramAndCo.h"
-//#include "shape.h"
 #include "primitive.others.h"
 
 
