@@ -42,14 +42,19 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
   methods may be called;  
 */
 
+#include "def.h"
+#ifdef DO_PARALLEL
+#include <omp.h>
+#endif
+#include <Basic_utils.h>
+
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "questions.h"
 #include "Coordinate_systems.h"
 #include "variogramAndCo.h"
 #include "Processes.h"
 #include "rf_interfaces.h"
-#ifdef DO_PARALLEL
-#include <omp.h>
-#endif
 
 /* 
  in CheckCovariance and other the following dimensions are used:
@@ -1163,6 +1168,8 @@ int alloc_pgs(model *cov, int dim) { // all what is necessary for dompp
   pgs_storage *pgs = cov->Spgs;
   assert(pgs->z == NULL);
 
+  // printf("alloc dim=%d %d\n", dim , dimP1);
+
   // to be save: everywhere +1 for loc->i_row although most not needed
   if ((pgs->supportmin = (double*) CALLOC(dimP1, sizeof(double))) == NULL ||
       (pgs->supportmax = (double*) CALLOC(dimP1, sizeof(double))) == NULL ||
