@@ -23,14 +23,15 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <Rmath.h>  
 #include <stdio.h>  
-//#include <stdlib.h>
-//#include <sys/timeb.h>
 #include <unistd.h>
  
+#include "def.h"
+#include <Basic_utils.h>
 #include <R_ext/Applic.h>
 #include <R_ext/Utils.h>     
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 
 #include "questions.h"
 #include "Processes.h"
@@ -241,12 +242,12 @@ int checktbmproc(model *cov) {
       err = CHECK(sub, OWNLOGDIM(0), OWNXDIM(0), VariogramType, 
 		       KERNEL, // wegen nutzer eingabe aniso und dem
 		       // allerersten check
-		       SYMMETRIC, SUBMODEL_DEP, EvaluationType);
+		       SYMMETRIC, SUBMODEL_DEP, GaussMethodType);
     } else {
       assert(COVNR != TBM_PROC_USER);
       for (int i=0; i<NSEL; i++) {	
 	if ((err = CHECK(sub, OWNLOGDIM(0), OWNXDIM(0), VariogramType, XONLY, 
-			 isoselect[i], SUBMODEL_DEP, EvaluationType))
+			 isoselect[i], SUBMODEL_DEP, GaussMethodType))
 	    == NOERROR) break;
       }
     }
@@ -566,7 +567,7 @@ int struct_tbmproc(model *cov, model **newmodel) {
 
   model  *modelB1;
 
-  if (cov->key != NULL) COV_DELETE(&(cov->key));
+  if (cov->key != NULL) COV_DELETE(&(cov->key), cov);
   if ((err = covcpy(&(cov->key), next)) != NOERROR) RETURN_ERR(err);
   modelB1 = cov->key;
   while (isGaussMethod(modelB1)) modelB1 = modelB1->sub[0];
@@ -682,9 +683,9 @@ int init_tbmproc(model *cov, gen_storage *S) {
   KEY_type *KT = cov->base;
    
   assert(s != NULL);
-
+  assert(KT != NULL);
   STRCPY(errorloc_save, KT->error_loc);
-  SPRINTF(KT->error_loc, "%.50s %.50s", errorloc_save, NAME(cov));
+  SPRINTF(KT->error_loc, "%.500s %.50s", errorloc_save, NAME(cov));
   cov->method = TBM;
 
   FRAME_ASSERT_GAUSS;
