@@ -22,9 +22,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */ 
   
  
-#include <Rmath.h>  
 #include <stdio.h>  
 #include <string.h> 
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "questions.h"
 #include "variogramAndCo.h"
 
@@ -788,7 +790,7 @@ SEXP CovLoc(SEXP reg, SEXP x, SEXP y, SEXP xdimOZ, SEXP lx,
   //   pmi(cov,0); printf("%d xdimOZ %d \n", Loc(cov)->xdimOZ, INTEGER(xdimOZ)[0]);
   partial_loc_null(cov);
   if (Loc(cov)->xdimOZ != INTEGER(xdimOZ)[0]) BUG;
-  return NULL;
+  return R_NilValue;
 }
 
 void CovIntern(int reg, double *x, double *y, long lx, long ly, double *value) {
